Node

Struct Node 

pub struct Node { /* private fields */ }
A single element of a savefile.

Implementations

Source

impl Node

pub fn new() -> Self

Create a new, empty, node.

pub fn parse(input: impl AsRef<str>) -> Result<Self, ParseError>

Parses a node from a string.

pub fn read(path: impl AsRef<Path>) -> Result<Self>

Reads a savefile from the file system.

pub fn write(&self, path: impl AsRef<Path>) -> Result<()>

Writes a savefile to the file system.

pub fn properties(&self) -> impl Iterator<Item = (&str, &str)>

Gets an iterator over all key-value properties on this node.

pub fn property(&self, key: impl AsRef<str>) -> Option<&str>

Gets the property value for a given key, if it exists. If multiple values are set, the first is returned.

pub fn has_property(&mut self, key: impl AsRef<str>) -> bool

Returns true if this node contains at least one property with the given key.

pub fn set_property(&mut self, key: impl Into<String>, value: impl Into<String>)

Sets the property value for a given key. If a value is already set, it is cleared.

pub fn add_property(&mut self, key: impl Into<String>, value: impl Into<String>)

Sets an additional property value for a given key. Existing values are kept.

pub fn clear_property( &mut self, key: impl AsRef<str>, ) -> impl Iterator<Item = String>

Removes all property values for the given key and returns them.

pub fn clear_properties( &mut self, ) -> impl Iterator<Item = (String, String)> + '_

Removes all property values for this node and returns them.

pub fn extend_properties<K, V>( &mut self, properties: impl IntoIterator<Item = (K, V)>, )
where K: Into<String>, V: Into<String>,

Adds the given key-value properties to this node.

pub fn children(&self) -> impl Iterator<Item = (&str, &Node)>

Gets an iterator over all children of this node.

pub fn children_mut(&mut self) -> impl Iterator<Item = (&str, &mut Node)>

Gets a mutable iterator over all children of this node.

pub fn child(&self, key: &str) -> Option<&Node>

Gets the child for a given key, if it exists. If multiple children exist, the first is returned.

pub fn child_mut(&mut self, key: &str) -> Option<&mut Node>

Gets a mutable reference to the child for a given key, if it exists. If multiple children exist, the first is returned.

pub fn has_child(&mut self, key: impl AsRef<str>) -> bool

Returns true if this node contains at least child with the given key.

pub fn set_child(&mut self, key: impl Into<String>, child: Node)

Sets the child value for a given key. If a child is already set, it is cleared.

pub fn add_child(&mut self, key: impl Into<String>, child: Node)

Sets an additional child value for a given key. Existing children are kept.

pub fn clear_child( &mut self, key: impl AsRef<str>, ) -> impl Iterator<Item = Node>

Removes all children for the given key and returns them.

pub fn clear_children(&mut self) -> impl Iterator<Item = (String, Node)> + '_

Removes all children for this node and returns them.

pub fn extend_children<K>( &mut self, properties: impl IntoIterator<Item = (K, Node)>, )
where K: Into<String>,

Adds the given children to this node.